@@ -1,7 +1,7 @@
-#!/usr/bin/env perl
+#!/usr/bin/perl
 #                                      Hey, EMACS: -*- cperl -*-
 # manpage.pl - script to generate mlucas(1) man page from embedded Pod
-# Copyright (C) 2015-2019 Alex Vong <alexvong1995@gmail.com>
+# Copyright (C) 2015-2021 Alex Vong <alexvong1995 AT protonmail DOT com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -42,7 +42,7 @@ use Pod::Man;
 # my global variables
 my $ERR_USAGE = 67;
 my $PROG_NAME = "MLUCAS";
-my $PROG_VER = "Mlucas 17.1";
+my $PROG_VER = "Mlucas 20.1.1";
 my $SECTION_NAME = "User Commands";
 my $SECTION_NUM = "1";
 my $LAST_UPDATE = "2019-01-26";
@@ -57,7 +57,7 @@ chomp(my $GREET = <<'EOF');
 EOF
 chomp(my $INTRO = <<'EOF');
 .\" mlucas.1 - man page of mlucas written for Debian GNU/Linux
-.\" Copyright (C) 2015, 2017 Alex Vong <alexvong1995@gmail.com>,
+.\" Copyright (C) 2015-2021 Alex Vong <alexvong1995 AT protonmail DOT com>
 .\"
 .\" This program is free software; you can redistribute it and/or modify
 .\" it under the terms of the GNU General Public License as published by
@@ -293,6 +293,11 @@ _END_NO_BLANK_LINES
 
 =head1 DESCRIPTION
 
+[B<FIXME:> This man page is potentially outdated, please see the
+L<online documentation|https://www.mersenneforum.org/mayer/README.html>
+or the help text located in F</usr/share/doc/mlucas/help.txt.gz>
+for up-to-date information.]
+
 This manual page documents briefly the B<mlucas> command.
 
 B<mlucas> is an open-source (and free/libre) program
@@ -850,10 +855,11 @@ It is possible that B<mlucas> returns I<1>
 instead of I<255> as exit status value.
 
 For problems regarding the program B<mlucas>,
-please contact the author Ernst W. Mayer <ewmayer@aol.com>.
+please contact the author Ernst W. Mayer <ewmayer AT aol DOT com>.
 For installation and documentation related problems
 regarding the Debian package and this manual,
-please use B<reportbug>(1) to contact Alex Vong <alexvong1995@gmail.com>.
+please use B<reportbug>(1) to
+contact Alex Vong <alexvong1995 AT protonmail DOT com>.
 
 =head1 EXAMPLE
 
